[U-Boot] [PATCH v2 15/32] dm: part: Rename some partition functions

Simon Glass sjg at chromium.org
Mon Feb 29 23:25:48 CET 2016


Rename three partition functions so that they start with part_. This makes
it clear what they relate to.

Signed-off-by: Simon Glass <sjg at chromium.org>
---

Changes in v2: None

 board/cm5200/fwupdate.c   |  2 +-
 cmd/ide.c                 |  6 +++---
 cmd/mmc.c                 |  2 +-
 cmd/part.c                |  8 ++++----
 cmd/read.c                |  2 +-
 cmd/sata.c                |  6 +++---
 cmd/scsi.c                |  6 +++---
 cmd/usb.c                 |  4 ++--
 common/fb_mmc.c           | 10 +++++-----
 common/spl/spl_ext.c      |  6 ++----
 common/spl/spl_mmc.c      |  2 +-
 common/usb_storage.c      |  2 +-
 disk/part.c               | 12 ++++++------
 disk/part_amiga.c         |  4 ++--
 disk/part_dos.c           | 19 +++++++++----------
 disk/part_efi.c           | 10 +++++-----
 disk/part_iso.c           | 17 +++++++++--------
 disk/part_mac.c           |  4 ++--
 drivers/block/pata_bfin.c |  2 +-
 drivers/block/sandbox.c   |  2 +-
 drivers/block/systemace.c |  2 +-
 drivers/dfu/dfu_mmc.c     |  2 +-
 drivers/mmc/mmc.c         |  2 +-
 fs/fat/fat.c              |  2 +-
 include/part.h            | 21 ++++++++++-----------
 25 files changed, 76 insertions(+), 79 deletions(-)

diff --git a/board/cm5200/fwupdate.c b/board/cm5200/fwupdate.c
index d5064c1..2ed90de 100644
--- a/board/cm5200/fwupdate.c
+++ b/board/cm5200/fwupdate.c
@@ -117,7 +117,7 @@ static int load_rescue_image(ulong addr)
 
 	/* Detect partition */
 	for (partno = -1, i = 0; i < 6; i++) {
-		if (get_partition_info(stor_dev, i, &info) == 0) {
+		if (part_get_info(stor_dev, i, &info) == 0) {
 			if (fat_register_device(stor_dev, i) == 0) {
 				/* Check if rescue image is present */
 				FW_DEBUG("Looking for firmware directory '%s'"
diff --git a/cmd/ide.c b/cmd/ide.c
index 06202c5..01b91b5 100644
--- a/cmd/ide.c
+++ b/cmd/ide.c
@@ -137,7 +137,7 @@ int do_ide(cmd_tbl_t *cmdtp, int flag, int argc, char *const argv[])
 					++ok;
 					if (dev)
 						putc('\n');
-					print_part(&ide_dev_desc[dev]);
+					part_print(&ide_dev_desc[dev]);
 				}
 			}
 			if (!ok) {
@@ -171,7 +171,7 @@ int do_ide(cmd_tbl_t *cmdtp, int flag, int argc, char *const argv[])
 			int dev = (int) simple_strtoul(argv[2], NULL, 10);
 
 			if (ide_dev_desc[dev].part_type != PART_TYPE_UNKNOWN) {
-				print_part(&ide_dev_desc[dev]);
+				part_print(&ide_dev_desc[dev]);
 			} else {
 				printf("\nIDE device %d not available\n",
 				       dev);
@@ -435,7 +435,7 @@ void ide_init(void)
 
 		if ((ide_dev_desc[i].lba > 0) && (ide_dev_desc[i].blksz > 0)) {
 			/* initialize partition type */
-			init_part(&ide_dev_desc[i]);
+			part_init(&ide_dev_desc[i]);
 			if (curr_device < 0)
 				curr_device = i;
 		}
diff --git a/cmd/mmc.c b/cmd/mmc.c
index ab59e7f..fb4382e 100644
--- a/cmd/mmc.c
+++ b/cmd/mmc.c
@@ -433,7 +433,7 @@ static int do_mmc_part(cmd_tbl_t *cmdtp, int flag,
 
 	mmc_dev = mmc_get_dev(curr_device);
 	if (mmc_dev != NULL && mmc_dev->type != DEV_TYPE_UNKNOWN) {
-		print_part(mmc_dev);
+		part_print(mmc_dev);
 		return CMD_RET_SUCCESS;
 	}
 
diff --git a/cmd/part.c b/cmd/part.c
index 415b38a..414031e 100644
--- a/cmd/part.c
+++ b/cmd/part.c
@@ -92,7 +92,7 @@ static int do_part_list(int argc, char * const argv[])
 
 		for (p = 1; p < 128; p++) {
 			char t[5];
-			int r = get_partition_info(desc, p, &info);
+			int r = part_get_info(desc, p, &info);
 
 			if (r != 0)
 				continue;
@@ -107,7 +107,7 @@ static int do_part_list(int argc, char * const argv[])
 		return 0;
 	}
 
-	print_part(desc);
+	part_print(desc);
 
 	return 0;
 }
@@ -132,7 +132,7 @@ static int do_part_start(int argc, char * const argv[])
 	if (ret < 0)
 		return 1;
 
-	err = get_partition_info(desc, part, &info);
+	err = part_get_info(desc, part, &info);
 	if (err)
 		return 1;
 
@@ -166,7 +166,7 @@ static int do_part_size(int argc, char * const argv[])
 	if (ret < 0)
 		return 1;
 
-	err = get_partition_info(desc, part, &info);
+	err = part_get_info(desc, part, &info);
 	if (err)
 		return 1;
 
diff --git a/cmd/read.c b/cmd/read.c
index 12ac1659..f8d766a 100644
--- a/cmd/read.c
+++ b/cmd/read.c
@@ -50,7 +50,7 @@ int do_read(cmd_tbl_t *cmdtp, int flag, int argc, char * const argv[])
 	cnt = simple_strtoul(argv[5], NULL, 16);
 
 	if (part != 0) {
-		if (get_partition_info(dev_desc, part, &part_info)) {
+		if (part_get_info(dev_desc, part, &part_info)) {
 			printf("Cannot find partition %d\n", part);
 			return 1;
 		}
diff --git a/cmd/sata.c b/cmd/sata.c
index a1faf2d..8b1f19c 100644
--- a/cmd/sata.c
+++ b/cmd/sata.c
@@ -52,7 +52,7 @@ int __sata_initialize(void)
 			rc = scan_sata(i);
 			if (!rc && (sata_dev_desc[i].lba > 0) &&
 				(sata_dev_desc[i].blksz > 0))
-				init_part(&sata_dev_desc[i]);
+				part_init(&sata_dev_desc[i]);
 		}
 	}
 	sata_curr_device = 0;
@@ -131,7 +131,7 @@ static int do_sata(cmd_tbl_t *cmdtp, int flag, int argc, char * const argv[])
 					++ok;
 					if (dev)
 						putc ('\n');
-					print_part(&sata_dev_desc[dev]);
+					part_print(&sata_dev_desc[dev]);
 				}
 			}
 			if (!ok) {
@@ -164,7 +164,7 @@ static int do_sata(cmd_tbl_t *cmdtp, int flag, int argc, char * const argv[])
 			int dev = (int)simple_strtoul(argv[2], NULL, 10);
 
 			if (sata_dev_desc[dev].part_type != PART_TYPE_UNKNOWN) {
-				print_part(&sata_dev_desc[dev]);
+				part_print(&sata_dev_desc[dev]);
 			} else {
 				printf("\nSATA device %d not available\n", dev);
 				rc = 1;
diff --git a/cmd/scsi.c b/cmd/scsi.c
index dff811b..de0651c 100644
--- a/cmd/scsi.c
+++ b/cmd/scsi.c
@@ -156,7 +156,7 @@ void scsi_scan(int mode)
 			scsi_dev_desc[scsi_max_devs].log2blksz =
 				LOG2(scsi_dev_desc[scsi_max_devs].blksz);
 			scsi_dev_desc[scsi_max_devs].type=perq;
-			init_part(&scsi_dev_desc[scsi_max_devs]);
+			part_init(&scsi_dev_desc[scsi_max_devs]);
 removable:
 			if(mode==1) {
 				printf ("  Device %d: ", scsi_max_devs);
@@ -301,7 +301,7 @@ int do_scsi (cmd_tbl_t *cmdtp, int flag, int argc, char * const argv[])
 						if (dev)
 							printf("\n");
 						debug ("print_part of %x\n",dev);
-							print_part(&scsi_dev_desc[dev]);
+						part_print(&scsi_dev_desc[dev]);
 					}
 				}
 				if (!ok)
@@ -329,7 +329,7 @@ int do_scsi (cmd_tbl_t *cmdtp, int flag, int argc, char * const argv[])
 			if (strncmp(argv[1],"part",4) == 0) {
 				int dev = (int)simple_strtoul(argv[2], NULL, 10);
 				if(scsi_dev_desc[dev].type != DEV_TYPE_UNKNOWN) {
-					print_part(&scsi_dev_desc[dev]);
+					part_print(&scsi_dev_desc[dev]);
 				}
 				else {
 					printf ("\nSCSI device %d not available\n", dev);
diff --git a/cmd/usb.c b/cmd/usb.c
index 5f3b06a..53fd6ad 100644
--- a/cmd/usb.c
+++ b/cmd/usb.c
@@ -727,7 +727,7 @@ static int do_usb(cmd_tbl_t *cmdtp, int flag, int argc, char * const argv[])
 					if (devno)
 						printf("\n");
 					debug("print_part of %x\n", devno);
-					print_part(stor_dev);
+					part_print(stor_dev);
 				}
 			}
 		} else {
@@ -737,7 +737,7 @@ static int do_usb(cmd_tbl_t *cmdtp, int flag, int argc, char * const argv[])
 			    stor_dev->type != DEV_TYPE_UNKNOWN) {
 				ok++;
 				debug("print_part of %x\n", devno);
-				print_part(stor_dev);
+				part_print(stor_dev);
 			}
 		}
 		if (!ok) {
diff --git a/common/fb_mmc.c b/common/fb_mmc.c
index 4324f58..d5c9135 100644
--- a/common/fb_mmc.c
+++ b/common/fb_mmc.c
@@ -25,12 +25,12 @@ struct fb_mmc_sparse {
 	struct blk_desc	*dev_desc;
 };
 
-static int get_partition_info_efi_by_name_or_alias(struct blk_desc *dev_desc,
+static int part_get_info_efi_by_name_or_alias(struct blk_desc *dev_desc,
 		const char *name, disk_partition_t *info)
 {
 	int ret;
 
-	ret = get_partition_info_efi_by_name(dev_desc, name, info);
+	ret = part_get_info_efi_by_name(dev_desc, name, info);
 	if (ret) {
 		/* strlen("fastboot_partition_alias_") + 32(part_name) + 1 */
 		char env_alias_name[25 + 32 + 1];
@@ -41,7 +41,7 @@ static int get_partition_info_efi_by_name_or_alias(struct blk_desc *dev_desc,
 		strncat(env_alias_name, name, 32);
 		aliased_part_name = getenv(env_alias_name);
 		if (aliased_part_name != NULL)
-			ret = get_partition_info_efi_by_name(dev_desc,
+			ret = part_get_info_efi_by_name(dev_desc,
 					aliased_part_name, info);
 	}
 	return ret;
@@ -131,7 +131,7 @@ void fb_mmc_flash_write(const char *cmd, unsigned int session_id,
 		printf("........ success\n");
 		fastboot_okay(response_str, "");
 		return;
-	} else if (get_partition_info_efi_by_name_or_alias(dev_desc, cmd, &info)) {
+	} else if (part_get_info_efi_by_name_or_alias(dev_desc, cmd, &info)) {
 		error("cannot find partition: '%s'\n", cmd);
 		fastboot_fail(response_str, "cannot find partition");
 		return;
@@ -186,7 +186,7 @@ void fb_mmc_erase(const char *cmd, char *response)
 		return;
 	}
 
-	ret = get_partition_info_efi_by_name_or_alias(dev_desc, cmd, &info);
+	ret = part_get_info_efi_by_name_or_alias(dev_desc, cmd, &info);
 	if (ret) {
 		error("cannot find partition: '%s'", cmd);
 		fastboot_fail(response_str, "cannot find partition");
diff --git a/common/spl/spl_ext.c b/common/spl/spl_ext.c
index d29d229..b77dbf4 100644
--- a/common/spl/spl_ext.c
+++ b/common/spl/spl_ext.c
@@ -22,8 +22,7 @@ int spl_load_image_ext(struct blk_desc *block_dev,
 	header = (struct image_header *)(CONFIG_SYS_TEXT_BASE -
 						sizeof(struct image_header));
 
-	if (get_partition_info(block_dev,
-			       partition, &part_info)) {
+	if (part_get_info(block_dev, partition, &part_info)) {
 		printf("spl: no partition table found\n");
 		return -1;
 	}
@@ -71,8 +70,7 @@ int spl_load_image_ext_os(struct blk_desc *block_dev, int partition)
 	disk_partition_t part_info = {};
 	__maybe_unused char *file;
 
-	if (get_partition_info(block_dev,
-			       partition, &part_info)) {
+	if (part_get_info(block_dev, partition, &part_info)) {
 		printf("spl: no partition table found\n");
 		return -1;
 	}
diff --git a/common/spl/spl_mmc.c b/common/spl/spl_mmc.c
index c27a250..5204f52 100644
--- a/common/spl/spl_mmc.c
+++ b/common/spl/spl_mmc.c
@@ -122,7 +122,7 @@ static int mmc_load_image_raw_partition(struct mmc *mmc, int partition)
 	disk_partition_t info;
 	int err;
 
-	err = get_partition_info(&mmc->block_dev, partition, &info);
+	err = part_get_info(&mmc->block_dev, partition, &info);
 	if (err) {
 #ifdef CONFIG_SPL_LIBCOMMON_SUPPORT
 		puts("spl: partition error\n");
diff --git a/common/usb_storage.c b/common/usb_storage.c
index ca5aeea..e105a95 100644
--- a/common/usb_storage.c
+++ b/common/usb_storage.c
@@ -1374,7 +1374,7 @@ int usb_stor_get_info(struct usb_device *dev, struct us_data *ss,
 	debug(" address %d\n", dev_desc->target);
 	debug("partype: %d\n", dev_desc->part_type);
 
-	init_part(dev_desc);
+	part_init(dev_desc);
 
 	debug("partype: %d\n", dev_desc->part_type);
 	return 1;
diff --git a/disk/part.c b/disk/part.c
index 978b85c..9a78cce 100644
--- a/disk/part.c
+++ b/disk/part.c
@@ -267,7 +267,7 @@ void dev_print (struct blk_desc *dev_desc)
 
 #ifdef HAVE_BLOCK_DEVICE
 
-void init_part(struct blk_desc *dev_desc)
+void part_init(struct blk_desc *dev_desc)
 {
 	struct part_driver *drv =
 		ll_entry_start(struct part_driver, part_driver);
@@ -329,7 +329,7 @@ static void print_part_header(const char *type, struct blk_desc *dev_desc)
 #endif /* any CONFIG_..._PARTITION */
 }
 
-void print_part(struct blk_desc *dev_desc)
+void part_print(struct blk_desc *dev_desc)
 {
 	struct part_driver *drv;
 
@@ -348,7 +348,7 @@ void print_part(struct blk_desc *dev_desc)
 
 #endif /* HAVE_BLOCK_DEVICE */
 
-int get_partition_info(struct blk_desc *dev_desc, int part,
+int part_get_info(struct blk_desc *dev_desc, int part,
 		       disk_partition_t *info)
 {
 #ifdef HAVE_BLOCK_DEVICE
@@ -432,7 +432,7 @@ int blk_get_device_by_str(const char *ifname, const char *dev_hwpart_str,
 	 * already loaded.
 	 */
 	if(hwpart != 0)
-		init_part(*dev_desc);
+		part_init(*dev_desc);
 #endif
 
 cleanup:
@@ -607,7 +607,7 @@ int blk_get_device_part_str(const char *ifname, const char *dev_part_str,
 	 * other than "auto", use that partition number directly.
 	 */
 	if (part != PART_AUTO) {
-		ret = get_partition_info(*dev_desc, part, info);
+		ret = part_get_info(*dev_desc, part, info);
 		if (ret) {
 			printf("** Invalid partition %d **\n", part);
 			goto cleanup;
@@ -619,7 +619,7 @@ int blk_get_device_part_str(const char *ifname, const char *dev_part_str,
 		 */
 		part = 0;
 		for (p = 1; p <= MAX_SEARCH_PARTITIONS; p++) {
-			ret = get_partition_info(*dev_desc, p, info);
+			ret = part_get_info(*dev_desc, p, info);
 			if (ret)
 				continue;
 
diff --git a/disk/part_amiga.c b/disk/part_amiga.c
index 0f569f0..d323b4b 100644
--- a/disk/part_amiga.c
+++ b/disk/part_amiga.c
@@ -291,7 +291,7 @@ static struct partition_block *find_partition(struct blk_desc *dev_desc,
 /*
  * Get info about a partition
  */
-static int get_partition_info_amiga(struct blk_desc *dev_desc, int part,
+static int part_get_info_amiga(struct blk_desc *dev_desc, int part,
 				    disk_partition_t *info)
 {
     struct partition_block *p = find_partition(dev_desc, part-1);
@@ -382,7 +382,7 @@ static void print_part_amiga(struct blk_desc *dev_desc)
 U_BOOT_PART_TYPE(amiga) = {
 	.name		= "AMIGA",
 	.part_type	= PART_TYPE_AMIGA,
-	.get_info	= get_partition_info_amiga,
+	.get_info	= part_get_info_amiga,
 	.print		= print_part_amiga,
 	.test		= test_part_amiga,
 };
diff --git a/disk/part_dos.c b/disk/part_dos.c
index 7567ed3..4a56391 100644
--- a/disk/part_dos.c
+++ b/disk/part_dos.c
@@ -167,11 +167,10 @@ static void print_partition_extended(struct blk_desc *dev_desc,
 
 /*  Print a partition that is relative to its Extended partition table
  */
-static int get_partition_info_extended(struct blk_desc *dev_desc,
-				       lbaint_t ext_part_sector,
-				       lbaint_t relative, int part_num,
-				       int which_part, disk_partition_t *info,
-				       unsigned int disksig)
+static int part_get_info_extended(struct blk_desc *dev_desc,
+				  lbaint_t ext_part_sector, lbaint_t relative,
+				  int part_num, int which_part,
+				  disk_partition_t *info, unsigned int disksig)
 {
 	ALLOC_CACHE_ALIGN_BUFFER(unsigned char, buffer, dev_desc->blksz);
 	dos_partition_t *pt;
@@ -259,7 +258,7 @@ static int get_partition_info_extended(struct blk_desc *dev_desc,
 			lbaint_t lba_start
 				= le32_to_int (pt->start4) + relative;
 
-			return get_partition_info_extended (dev_desc, lba_start,
+			return part_get_info_extended(dev_desc, lba_start,
 				 ext_part_sector == 0 ? lba_start : relative,
 				 part_num, which_part, info, disksig);
 		}
@@ -289,16 +288,16 @@ void print_part_dos(struct blk_desc *dev_desc)
 	print_partition_extended(dev_desc, 0, 0, 1, 0);
 }
 
-int get_partition_info_dos(struct blk_desc *dev_desc, int part,
-			   disk_partition_t *info)
+int part_get_info_dos(struct blk_desc *dev_desc, int part,
+		      disk_partition_t *info)
 {
-	return get_partition_info_extended(dev_desc, 0, 0, 1, part, info, 0);
+	return part_get_info_extended(dev_desc, 0, 0, 1, part, info, 0);
 }
 
 U_BOOT_PART_TYPE(dos) = {
 	.name		= "DOS",
 	.part_type	= PART_TYPE_DOS,
-	.get_info	= part_get_info_ptr(get_partition_info_dos),
+	.get_info	= part_get_info_ptr(part_get_info_dos),
 	.print		= part_print_ptr(print_part_dos),
 	.test		= test_part_dos,
 };
diff --git a/disk/part_efi.c b/disk/part_efi.c
index 3471b75..209a671 100644
--- a/disk/part_efi.c
+++ b/disk/part_efi.c
@@ -237,8 +237,8 @@ void print_part_efi(struct blk_desc *dev_desc)
 	return;
 }
 
-int get_partition_info_efi(struct blk_desc *dev_desc, int part,
-			   disk_partition_t *info)
+int part_get_info_efi(struct blk_desc *dev_desc, int part,
+		      disk_partition_t *info)
 {
 	ALLOC_CACHE_ALIGN_BUFFER_PAD(gpt_header, gpt_head, 1, dev_desc->blksz);
 	gpt_entry *gpt_pte = NULL;
@@ -300,13 +300,13 @@ int get_partition_info_efi(struct blk_desc *dev_desc, int part,
 	return 0;
 }
 
-int get_partition_info_efi_by_name(struct blk_desc *dev_desc,
+int part_get_info_efi_by_name(struct blk_desc *dev_desc,
 	const char *name, disk_partition_t *info)
 {
 	int ret;
 	int i;
 	for (i = 1; i < GPT_ENTRY_NUMBERS; i++) {
-		ret = get_partition_info_efi(dev_desc, i, info);
+		ret = part_get_info_efi(dev_desc, i, info);
 		if (ret != 0) {
 			/* no more entries in table */
 			return -1;
@@ -962,7 +962,7 @@ static int is_pte_valid(gpt_entry * pte)
 U_BOOT_PART_TYPE(a_efi) = {
 	.name		= "EFI",
 	.part_type	= PART_TYPE_EFI,
-	.get_info	= part_get_info_ptr(get_partition_info_efi),
+	.get_info	= part_get_info_ptr(part_get_info_efi),
 	.print		= part_print_ptr(print_part_efi),
 	.test		= test_part_efi,
 };
diff --git a/disk/part_iso.c b/disk/part_iso.c
index 1d72d23..a1cf358 100644
--- a/disk/part_iso.c
+++ b/disk/part_iso.c
@@ -46,8 +46,8 @@ static inline unsigned short le16_to_int(unsigned char *le16)
 
 
 /* only boot records will be listed as valid partitions */
-int get_partition_info_iso_verb(struct blk_desc *dev_desc, int part_num,
-				disk_partition_t *info, int verb)
+int part_get_info_iso_verb(struct blk_desc *dev_desc, int part_num,
+			   disk_partition_t *info, int verb)
 {
 	int i,offset,entry_num;
 	unsigned short *chksumbuf;
@@ -217,17 +217,18 @@ found:
 	return 0;
 }
 
-static int get_partition_info_iso(struct blk_desc *dev_desc, int part_num,
+static int part_get_info_iso(struct blk_desc *dev_desc, int part_num,
 				  disk_partition_t *info)
 {
-	return(get_partition_info_iso_verb(dev_desc, part_num, info, 1));
+	return part_get_info_iso_verb(dev_desc, part_num, info, 1);
 }
 
 static void print_part_iso(struct blk_desc *dev_desc)
 {
 	disk_partition_t info;
 	int i;
-	if(get_partition_info_iso_verb(dev_desc,0,&info,0)==-1) {
+
+	if (part_get_info_iso_verb(dev_desc, 0, &info, 0) == -1) {
 		printf("** No boot partition found on device %d **\n",dev_desc->dev);
 		return;
 	}
@@ -237,20 +238,20 @@ static void print_part_iso(struct blk_desc *dev_desc)
 		printf(" %2d " LBAFU " " LBAFU " %6ld %.32s\n",
 		       i, info.start, info.size, info.blksz, info.type);
 		i++;
-	} while (get_partition_info_iso_verb(dev_desc,i,&info,0)!=-1);
+	} while (part_get_info_iso_verb(dev_desc, i, &info, 0) != -1);
 }
 
 static int test_part_iso(struct blk_desc *dev_desc)
 {
 	disk_partition_t info;
 
-	return(get_partition_info_iso_verb(dev_desc,0,&info,0));
+	return part_get_info_iso_verb(dev_desc, 0, &info, 0);
 }
 
 U_BOOT_PART_TYPE(iso) = {
 	.name		= "ISO",
 	.part_type	= PART_TYPE_ISO,
-	.get_info	= get_partition_info_iso,
+	.get_info	= part_get_info_iso,
 	.print		= print_part_iso,
 	.test		= test_part_iso,
 };
diff --git a/disk/part_mac.c b/disk/part_mac.c
index 3fb3b16..6192723 100644
--- a/disk/part_mac.c
+++ b/disk/part_mac.c
@@ -213,7 +213,7 @@ static int part_mac_read_pdb(struct blk_desc *dev_desc, int part,
 	/* NOTREACHED */
 }
 
-static int get_partition_info_mac(struct blk_desc *dev_desc, int part,
+static int part_get_info_mac(struct blk_desc *dev_desc, int part,
 				  disk_partition_t *info)
 {
 	ALLOC_CACHE_ALIGN_BUFFER(mac_driver_desc_t, ddesc, 1);
@@ -240,7 +240,7 @@ static int get_partition_info_mac(struct blk_desc *dev_desc, int part,
 U_BOOT_PART_TYPE(mac) = {
 	.name		= "MAC",
 	.part_type	= PART_TYPE_MAC,
-	.get_info	= get_partition_info_mac,
+	.get_info	= part_get_info_mac,
 	.print		= print_part_mac,
 	.test		= test_part_mac,
 };
diff --git a/drivers/block/pata_bfin.c b/drivers/block/pata_bfin.c
index c2673bd..26569d7 100644
--- a/drivers/block/pata_bfin.c
+++ b/drivers/block/pata_bfin.c
@@ -965,7 +965,7 @@ int scan_sata(int dev)
 		/* Probe device and set xfer mode */
 		bfin_ata_identify(ap, dev%PATA_DEV_NUM_PER_PORT);
 		bfin_ata_set_Feature_cmd(ap, dev%PATA_DEV_NUM_PER_PORT);
-		init_part(&sata_dev_desc[dev]);
+		part_init(&sata_dev_desc[dev]);
 		return 0;
 	}
 
diff --git a/drivers/block/sandbox.c b/drivers/block/sandbox.c
index dd21400..093e133 100644
--- a/drivers/block/sandbox.c
+++ b/drivers/block/sandbox.c
@@ -98,7 +98,7 @@ int host_dev_bind(int dev, char *filename)
 	blk_dev->block_write = host_block_write;
 	blk_dev->dev = dev;
 	blk_dev->part_type = PART_TYPE_UNKNOWN;
-	init_part(blk_dev);
+	part_init(blk_dev);
 
 	return 0;
 }
diff --git a/drivers/block/systemace.c b/drivers/block/systemace.c
index ea18c0d..b921dcd 100644
--- a/drivers/block/systemace.c
+++ b/drivers/block/systemace.c
@@ -124,7 +124,7 @@ struct blk_desc *systemace_get_dev(int dev)
 		 */
 		ace_writew(width == 8 ? 0 : 0x0001, 0);
 
-		init_part(&systemace_dev);
+		part_init(&systemace_dev);
 
 	}
 
diff --git a/drivers/dfu/dfu_mmc.c b/drivers/dfu/dfu_mmc.c
index bfac91a..faece88 100644
--- a/drivers/dfu/dfu_mmc.c
+++ b/drivers/dfu/dfu_mmc.c
@@ -355,7 +355,7 @@ int dfu_fill_entity_mmc(struct dfu_entity *dfu, char *devstr, char *s)
 		int mmcdev = second_arg;
 		int mmcpart = third_arg;
 
-		if (get_partition_info(blk_dev, mmcpart, &partinfo) != 0) {
+		if (part_get_info(blk_dev, mmcpart, &partinfo) != 0) {
 			error("Couldn't find part #%d on mmc device #%d\n",
 			      mmcpart, mmcdev);
 			return -ENODEV;
diff --git a/drivers/mmc/mmc.c b/drivers/mmc/mmc.c
index b19b328..94afbb1 100644
--- a/drivers/mmc/mmc.c
+++ b/drivers/mmc/mmc.c
@@ -1495,7 +1495,7 @@ static int mmc_startup(struct mmc *mmc)
 	mmc->block_dev.revision[0] = 0;
 #endif
 #if !defined(CONFIG_SPL_BUILD) || defined(CONFIG_SPL_LIBDISK_SUPPORT)
-	init_part(&mmc->block_dev);
+	part_init(&mmc->block_dev);
 #endif
 
 	return 0;
diff --git a/fs/fat/fat.c b/fs/fat/fat.c
index 2cef3bd..47f077d 100644
--- a/fs/fat/fat.c
+++ b/fs/fat/fat.c
@@ -97,7 +97,7 @@ int fat_register_device(struct blk_desc *dev_desc, int part_no)
 	cur_dev = NULL;
 
 	/* Read the partition table, if present */
-	if (get_partition_info(dev_desc, part_no, &info)) {
+	if (part_get_info(dev_desc, part_no, &info)) {
 		if (part_no != 0) {
 			printf("** Partition %d not valid on device %d **\n",
 					part_no, dev_desc->dev);
diff --git a/include/part.h b/include/part.h
index 544b056..6d8f520 100644
--- a/include/part.h
+++ b/include/part.h
@@ -96,10 +96,9 @@ struct blk_desc *host_get_dev(int dev);
 int host_get_dev_err(int dev, struct blk_desc **blk_devp);
 
 /* disk/part.c */
-int get_partition_info(struct blk_desc *dev_desc, int part,
-		       disk_partition_t *info);
-void print_part(struct blk_desc *dev_desc);
-void init_part(struct blk_desc *dev_desc);
+int part_get_info(struct blk_desc *dev_desc, int part, disk_partition_t *info);
+void part_print(struct blk_desc *dev_desc);
+void part_init(struct blk_desc *dev_desc);
 void dev_print(struct blk_desc *dev_desc);
 
 /**
@@ -179,10 +178,10 @@ static inline struct blk_desc *systemace_get_dev(int dev) { return NULL; }
 static inline struct blk_desc *mg_disk_get_dev(int dev) { return NULL; }
 static inline struct blk_desc *host_get_dev(int dev) { return NULL; }
 
-static inline int get_partition_info(struct blk_desc *dev_desc, int part,
-				     disk_partition_t *info) { return -1; }
-static inline void print_part(struct blk_desc *dev_desc) {}
-static inline void init_part(struct blk_desc *dev_desc) {}
+static inline int part_get_info(struct blk_desc *dev_desc, int part,
+				disk_partition_t *info) { return -1; }
+static inline void part_print(struct blk_desc *dev_desc) {}
+static inline void part_init(struct blk_desc *dev_desc) {}
 static inline void dev_print(struct blk_desc *dev_desc) {}
 static inline int blk_get_device_by_str(const char *ifname, const char *dev_str,
 					struct blk_desc **dev_desc)
@@ -252,7 +251,7 @@ struct part_driver {
 #include <part_efi.h>
 /* disk/part_efi.c */
 /**
  * get_partition_info_efi_by_name() - Find the specified GPT partition table entry
  *
  * @param dev_desc - block device descriptor
  * @param gpt_name - the specified table entry name
@@ -260,8 +259,8 @@ struct part_driver {
  *
  * @return - '0' on match, '-1' on no match, otherwise error
  */
-int get_partition_info_efi_by_name(struct blk_desc *dev_desc,
-	const char *name, disk_partition_t *info);
+int part_get_info_efi_by_name(struct blk_desc *dev_desc,
+			      const char *name, disk_partition_t *info);
 
 /**
  * write_gpt_table() - Write the GUID Partition Table to disk
@@ -252,7 +251,7 @@ struct part_driver {
 /* disk/part_efi.c */
 /**
- * get_partition_info_efi_by_name() - Find the specified GPT partition table entry
+ * part_get_info_efi_by_name() - Find the specified GPT partition table entry
  *
  * @param dev_desc - block device descriptor
-- 
2.7.0.rc3.207.g0ac5344



More information about the U-Boot mailing list